function handleKeyPress(e){
	var key = e.keyCode || e.which;
	if (key === 13) {
		calculateIncomeTax();
	}
}

function getTaxTable() {
	return [
		{a:0,      b:0,        c:0,    incomeLimit:355},
		{a:0.19,   b:67.4635,  c:355,  incomeLimit:395},
		{a:0.29,   b:106.9673, c:395,  incomeLimit:464},
		{a:0.21,   b:67.4642,  c:493,  incomeLimit:711},
		{a:0.3477, b:165.4431, c:711,  incomeLimit:1282},
		{a:0.3450, b:161.9815, c:1282, incomeLimit:1538},
		{a:0.39,   b:231.2123, c:1538, incomeLimit:3461},
		{a:0.49,   b:577.3662, c:3461, incomeLimit:99999999}
	];
}

function calculateIncomeTax() {
	var paymentFrequency = document.getElementById("payment-frequency").value;
	var income = document.getElementById("income").value;
	var tax = document.getElementById("tax").value;
	var tableStore = [];
	var frequencies = [
		{ frequency: "Annually", value: 1},
		{ frequency: "Quarterly", value: 4},
		{ frequency: "Monthly", value: 12},
		{ frequency: "Fortnightly", value: 26},
		{ frequency: "Weekly", value: 52}
	];
	
	if (income.trim().length === 0 || !income.trim()) {
		income = document.getElementById("income").placeholder;
	}
	
	for (var i = 0; i < frequencies.length; i++) {
		var grossSalary = 0;
		var netSalary = 0;
		var incomeTax = 0;
		
		if (tax === "Gross") {
			grossSalary = income * paymentFrequency/frequencies[i].value;
			incomeTax = calculateTax(grossSalary, frequencies[i].value);
			netSalary = grossSalary - incomeTax;
		}
		else {
			netSalary = income * paymentFrequency/frequencies[i].value;
			grossSalary = calculateGrossIncome(netSalary, frequencies[i].value);
			incomeTax = grossSalary - netSalary;
		}
		
		var row = [
			frequencies[i].frequency,
			Math.floor(grossSalary),
			Math.floor(incomeTax),
			Math.floor(netSalary)
		];
		tableStore.push(row);
	}
	
	var tableBody = document.getElementById("tableBody");
	var rowCount = tableBody.children.length;
	
	for (var i = rowCount-1; i > -1; i--) {
		tableBody.deleteRow(i);
	}
	
	for (var i = 0; i < tableStore.length; i++) {
		var tr = document.createElement("tr");
		for (var j = 0; j < tableStore[i].length; j++) {
			var td = document.createElement("td");
			if (j === 0) {
				td = document.createElement("th");
			}
			td.appendChild(document.createTextNode(j === 0 ? tableStore[i][j] : '$' + numberWithCommas(tableStore[i][j])));
			tr.appendChild(td);
		}
		tableBody.appendChild(tr);
	}
}

function calculateTax(income, frequency) {
	var incomeTaxItems = getTaxTable();

	var incomeTaxAmount = 0;
	var periodIncome = income * frequency/52;
	var bracketFound = false;
	
	for (var i = 0; i < incomeTaxItems.length; i++) {
		if (periodIncome < incomeTaxItems[i].incomeLimit && !bracketFound) {
			incomeTaxAmount = (incomeTaxItems[i].a * (Math.floor(periodIncome) + 0.99) - incomeTaxItems[i].b);
			bracketFound = true;
		}
	}
	
	return (incomeTaxAmount * 52/frequency);
}

function calculateGrossIncome(income, frequency) {
	var incomeTaxItems = getTaxTable();
	
	var grossAmount = 0;
	var periodIncome = income * frequency/52;				
	var matchFound = false;
	
	for (var i = 0; i < incomeTaxItems.length; i++) {
		var taxAtTopOfBand = (incomeTaxItems[i].incomeLimit * incomeTaxItems[i].a - incomeTaxItems[i].b);
		var netIncomeAtTopOfBand = incomeTaxItems[i].incomeLimit - taxAtTopOfBand;
		
		if (periodIncome < netIncomeAtTopOfBand && !matchFound) {
			grossAmount = ((periodIncome - incomeTaxItems[i].b) / (1 - incomeTaxItems[i].a));
			grossAmount = Math.floor(grossAmount) + 0.99;
			matchFound = true;
		}
	}
	
	return (grossAmount * 52/frequency);
}