function handleKeyPress(e){
	var key = e.keyCode || e.which;
	if (key === 13) {
		calculatePropertyFees();
	}
}

function getRegistrationFeesTable() {
	return [
		{state: 'VIC', value: 112.60},
		{state: 'NSW', value: 136.30},
		{state: 'NT',  value: 142},
		{state: 'TAS', value: 130.81},
		{state: 'SA',  value: 157},
		{state: 'WA',  value: 165.80},
		{state: 'QLD', value: 175},
		{state: 'ACT', value: 135}
	];
}

function calculatePropertyFees() {
	// Text fields
	var propertyPrice = document.getElementById("property-price").value;
	var loanAmount = document.getElementById("loan-amount").value;
	
	if (propertyPrice.trim().length === 0 || !propertyPrice.trim()) {
		propertyPrice = document.getElementById("property-price").placeholder;
	}
	if (loanAmount.trim().length === 0 || !loanAmount.trim()) {
		loanAmount = document.getElementById("loan-amount").placeholder;
	}
	
	// Drop down fields
	var state = document.getElementById("fee-dis").value;
	var securityType = document.getElementById("security-type").value;
	var transactionType = document.getElementById("transaction-type").value;
	var propertyPurpose = document.getElementById("property-purpose").value;
	
	// Checkboxes
	var cbFhb = document.getElementById("first-home-buyer");
	var cbFhbNSW = document.getElementById("first-home-buyer-nsw");
	var cbPr = document.getElementById("primary-residence");
	var cbHbcACT = document.getElementById("home-buyer-concession-act");
	
	// Checkbox labels
	var cbFhbLabel = document.getElementById("first-home-buyer-label");
	var cbFhbNSWLabel = document.getElementById("first-home-buyer-nsw-label");
	var cbHbcACTLabel = document.getElementById("home-buyer-concession-act-label");
	
	// Display fields and value variables for them
	var stampDuty = 0;
	var transferFee = 0;
	var registrationFee = 0;
	var total = 0;
	
	var stampDutySpan = document.getElementById("purchase-stamp-duty");
	var transferFeeSpan = document.getElementById("transfer-fee");
	var registrationFeeSpan = document.getElementById("registration-fee");
	var totalSpan = document.getElementById("total");
	
	// Hide/show specific checkboxes for ACT and NSW
	if (state === "ACT") {
		cbHbcACTLabel.style.display = "inline";
		cbFhbLabel.style.display = "inline";
		cbFhbNSWLabel.style.display = "none";
	}
	else if (state === "NSW") {
		cbHbcACT.checked = false;
		cbHbcACTLabel.style.display = "none";
		cbFhbLabel.style.display = "none";
		cbFhbNSWLabel.style.display = "inline";
	}
	else {
		cbHbcACT.checked = false;
		cbHbcACTLabel.style.display = "none";
		cbFhbNSWLabel.style.display = "none";
		cbFhbLabel.style.display = "inline";
	}
	
	// Enable/disable property price checkbox
	if (propertyPurpose === "Investment") {
		cbPr.checked = false;
		cbPr.disabled = true;
	}
	else {
		cbPr.disabled = false;
	}

	// Calculate stamp duty and transfer fee
	if (transactionType === "Purchase") {
		transferFee = calculateTransferFee(state, propertyPrice);
		stampDuty = calculatePurchaseStampDuty(state, propertyPrice, securityType, cbPr.checked, cbFhb.checked, cbHbcACT.checked);
	}
	else {
		transferFee = 0;
		stampDuty = 0;
	}
	
	// Get registration fee 
	var regFees = getRegistrationFeesTable();
	for (var i = 0; i < regFees.length; i++) {
		if (regFees[i].state === state) {
			registrationFee = regFees[i].value;
		}
	}
	
	// Calculate total
	total = stampDuty + transferFee + registrationFee;
	
	// Set text for all display fields
	stampDutySpan.innerHTML = "$" + numberWithCommas(stampDuty);
	transferFeeSpan.innerHTML = "$" + numberWithCommas(transferFee);
	registrationFeeSpan.innerHTML = "$" + numberWithCommas(registrationFee);
	totalSpan.innerHTML = "$" + numberWithCommas(total);
}

function calculateTransferFee(state, propertyPrice) {
	var temp = 0;
	var constant = 0;
	var rate = 0;
	var max = 0;
	var fee = 0;
	var value = 0;

	switch(state) {
		case "VIC"://updated June 25'2014
			//http://www.dse.vic.gov.au/property-titles-and-maps/land-titles-home/forms-guides-and-fees#Fees
			//updated 24 June'2014 gt & BC
			
			if (propertyPrice > 0){
				constant = 92.7;
				rate = 2.34;
				max = 3603;

				temp = propertyPrice / 1000;
				temp = Math.ceil(temp);

				value = (temp * rate) + constant;

				if (value > max)
				{
					value = max;
				}
			}
		break;
		
		case "QLD":
			// http://www.derm.qld.gov.au/services_resources/item_list.php?category_id=152&topic_id=4&page=1
			//updated 26 June'2013 gt & BC
			
			var transferLot = 33;
			fee = 175;

			if (propertyPrice > 180000) {
				temp = propertyPrice - 180000;
				temp = temp / 10000;
				temp = Math.ceil(temp);

				temp = fee + (temp * transferLot);
				value = temp;
			}
			else {
				value = fee;
			}
		break;

		case "TAS":
			//http://www.dpipwe.tas.gov.au/inter.nsf/ThemeNodes/JGAY-53F773?open
			//updated 24 June'2014 gt & BC
			
			if (propertyPrice > 0) {
				value = 200.43;
			}
		break;

		case "NSW":
			//http://www.lpi.nsw.gov.au/__data/assets/pdf_file/0004/183793/2013_06_LPI_fee_changes_from_1_July_2013.pdf
			//updated 24 June'2014 gt & BC
			
			if (propertyPrice > 0) {
				value = 136.3;
			}
		break;

		case "SA":
			// http://www.landservices.sa.gov.au/5publications/Fees_and_Services/
			// calculator - http://www.landservices.sa.gov.au/1Online_services/60Fee_Calculator/_Fee_Calculator/Default.aspx?sect=form&fid=110
			//updated 26 June'2013 gt & BC
			
			if (propertyPrice <= 5000) {
				value = 157;
			}
			else if (
				propertyPrice > 5000 &&
				propertyPrice <= 20000
			) {
				value = 174;
			}
			else if (
				propertyPrice > 20000 && 
				propertyPrice <= 40000
			) {
				value = 191;
			}
			else if ( 
				propertyPrice > 40000 && 
				propertyPrice <= 50000
			) {
				value = 268;
			}
			else if (propertyPrice > 50000) {
				rate = 79;
				constant = 268;
				temp = propertyPrice - 50000;
				temp = temp / 10000;
				temp = Math.ceil(temp);

				value = constant + (temp * rate);
			}
		break;

		case "ACT":
			//http://www.ors.act.gov.au/community/land_titles/forms_and_fees
			//update 26 june'12
			if (propertyPrice > 0) {
				value = 262;
			}
		break;

		case "WA":
			//http://www.landgate.wa.gov.au/docvault.nsf/web/PS_CIB/$FILE/CIB215.pdf
			//update 26 june'12
			
			if (propertyPrice <= 85000) {
				value = 165.80;
			}
			else if (
				propertyPrice > 85000 &&
				propertyPrice <= 120000
			) {
				value = 175.80;
			}
			else if (
				propertyPrice > 120000 &&
				propertyPrice <= 200000
			) {
				value = 195.80;
			}
			else if (propertyPrice > 200000) {
				//$20 for every $100 000 or part there of above $200 000
				fee = 195.80;
				temp = propertyPrice - 200000;
				temp = temp / 100000;
				temp = Math.ceil(temp);
				value = fee + (temp * 20);
			}

		break;

		case "NT": 
			// http://www.nt.gov.au/justice/bdm/land_title_office/fees.shtml
			//updated 24 June'2014 gt & BC
			
			if (propertyPrice > 0) {
				value = 142;
			}
		break;
	}

	return value;
}

function calculatePurchaseStampDuty(state, propertyPrice, securityType, primaryResidence, firstHomeBuyer, homeBuyerConcessionACT) {
	// This is to ensure that where the property type is investment, the FHB discounts won't apply
	if (
		firstHomeBuyer === true &&
		primaryResidence === false
	) {
		firstHomeBuyer = false;
	}

	var fhbConcession = 0; // First Home Buyers Concession
	var hbbConcession = 0; // NSW Home Builder Bonus Concession
	var rate = 0;
	var constant = 0;
	var reduceBy = 0;
	var rateType = "";

	switch(state) {

		case "VIC":

			// updated 17th June'2011
			// calculator-http://www.sro.vic.gov.au/SRO/SROCalcs.nsf/transfer?OpenForm&3&CD=24/08/2011&V=$130,000&E=0&PPR=N&fh=N&sd=&S=3&R=$2,870&#calc

			// Duty concession for FHB -  Land Transfer Duty was reduced by 20 per cent on 1 July 2011,
			// to be followed by additional 10 per cent cuts on 1 January 2013, 1 January 2014 and 1 September 2014,
			// totalling a cumulative 50 per cent reduction for settlement dates on or after 1 September 2014.

			// http://www.sro.vic.gov.au/sro/SROnav.nsf/childdocs/-34FAD0EFBAFF8BE0CA2575A100442101-E35A67FBAB847FF1CA2575D10080A69F-1F4F15D2B7E31144CA2576EE007AFC77-33F164285C8F118CCA2576EE007E3927?open

			//Reviewed 26/6/2013 - GT & BC - no change

			rateType = "Percentage";

			if(primaryResidence) {
				if ( propertyPrice <= 25000 ) {
					rate = 1.4;
					constant = 0;
					reduceBy = 0;
				}
				else if ( propertyPrice <= 130000 ) {
					rate = 2.4;
					constant = 350;
					reduceBy = 25000;
				}
				else if ( propertyPrice <= 440000 ) {
					rate = 5;
					constant = 2870;
					reduceBy = 130000;
				}
				else if ( propertyPrice <= 550000 ) {
					rate = 6;
					constant = 18370;
					reduceBy = 440000;
				}
				else if ( propertyPrice <= 960000 ) {
					rate = 6;
					constant = 28070;
					reduceBy = 550000;
				}
				else if ( propertyPrice > 960000 ) {
					rate = 5.5;
					constant = 0;
					reduceBy = 0;
				}
			}
			else {
				if ( propertyPrice <= 25000 ) {
					rate = 1.4;
					constant = 0;
					reduceBy = 0;
				}
				else if ( propertyPrice <= 130000 ) {
					rate = 2.4;
					constant = 350;
					reduceBy = 25000;
				}
				else if ( propertyPrice <= 960000 ) {
					rate = 6;
					constant = 2870;
					reduceBy = 130000;
				}
				else if ( propertyPrice > 960000 ) {
					rate = 5.5;
					constant = 0;
					reduceBy = 0;
				}
			}
			break;

		case "NSW":
			rateType = "Number";
			// Govt calculator - http://www.apps05.osr.nsw.gov.au/erevenue/calculators/index.php

			if (firstHomeBuyer) {
				// http://www.osr.nsw.gov.au/benefits/first_home/first_home_new_home/ - refer to First Home New Home Factsheet.

				switch (securityType) {
					case "Vacant Land":
						if ( propertyPrice > 0 && propertyPrice <= 350000 ) {
							rate = 0;
							constant = 0;
							reduceBy = 0;
						}
						else if ( propertyPrice > 350000 && propertyPrice <= 450000 ) {
							rate = 0.1574;
							constant = -55090;
							reduceBy = 0;
						}
						else if ( propertyPrice > 450000 && propertyPrice <= 1000000 ) {
							rate = 4.5;
							constant = 8990;
							reduceBy = 300000;
							rateType = "Part";
						}
						else if ( propertyPrice > 1000000 && propertyPrice <= 3000000 ) {
							rate = 5.5;
							constant = 40490;
							reduceBy = 1000000;
							rateType = "Part";
						}
						else if ( propertyPrice > 3000000 ) {//premium property duty
							rate = 7;
							constant = 150490;
							reduceBy = 3000000;
							rateType = "Part";
						}
						break;
					case "House":
						if ( propertyPrice > 0 && propertyPrice <= 550000 ) {
							rate = 0;
							constant = 0;
							reduceBy = 0;
						}
						else if ( propertyPrice > 550000 && propertyPrice <= 650000 ) {
							rate = 0.2474;
							constant = -136070;
							reduceBy = 0;
						}
						else if ( propertyPrice > 650000 && propertyPrice <= 1000000 ) {
							rate = 4.5;
							constant = 8990;
							reduceBy = 300000;
							rateType = "Part";
						}
						else if ( propertyPrice > 1000000 && propertyPrice <= 3000000 ) {
							rate = 5.5;
							constant = 40490;
							reduceBy = 1000000;
							rateType = "Part";
						}
						else if ( propertyPrice > 3000000 ) {// premium property duty
							rate = 7;
							constant = 150490;
							reduceBy = 3000000;
							rateType = "Part";
						}
						break;
				}
			}
			else { // http://www.osr.nsw.gov.au/lib/doc/factsheets/ofs_dut01.pdf
				//http://www.osr.nsw.gov.au/taxes/transfer_land/rates/
				//reviewed 26/6/13 - GT & BC - no change
				
				rateType = "Part";
				
				//$1.25 per $100 of part there of
				if ( propertyPrice > 0 && propertyPrice <= 14000 ) {
					rate = 1.25;
					constant = 0;
					reduceBy = 0;
				}
				else if ( propertyPrice > 14000 && propertyPrice <= 30000 ) {
					rate = 1.5;
					constant = 175;
					reduceBy = 14000;
				}
				else if ( propertyPrice > 30000 && propertyPrice <= 80000 ) {
					rate = 1.75;
					constant = 415;
					reduceBy = 30000;
				}
				else if ( propertyPrice > 80000 && propertyPrice <= 300000 ) {
					rate = 3.5;
					constant = 1290;
					reduceBy = 80000;
				}
				else if ( propertyPrice > 300000 && propertyPrice <= 1000000 ) {
					rate = 4.5;
					constant = 8990;
					reduceBy = 300000;
				}
				else if ( propertyPrice > 1000000 && propertyPrice <= 3000000 ) {
					rate = 5.5;
					constant = 40490;
					reduceBy = 1000000;
				}
				else if ( propertyPrice > 3000000 ) {// premium property duty
					rate = 7;
					constant = 150490;
					reduceBy = 3000000;
				}
			}
			break;

		case "SA":
			// http://www.revenuesa.sa.gov.au/stamps/sdreal.html

			rateType = "Part";
			if ( propertyPrice > 0 && propertyPrice < 12000 ) {
				rate = 1;
				constant = 0;
				reduceBy = 0;
			}
			else if ( propertyPrice >= 12000 && propertyPrice < 30000 ) {
				rate = 2;
				constant = 120;
				reduceBy = 12000;
			}
			else if ( propertyPrice >= 30000 && propertyPrice < 50000 ) {
				rate = 3;
				constant = 480;
				reduceBy = 30000;
			}
			else if ( propertyPrice >= 50000 && propertyPrice < 100000 ) {
				rate = 3.5;
				constant = 1080;
				reduceBy = 50000;
			}
			else if ( propertyPrice >= 100000 && propertyPrice < 200000 ) {
				rate = 4;
				constant = 2830;
				reduceBy = 100000;
			}
			else if ( propertyPrice >= 200000 && propertyPrice < 250000 ) {
				rate = 4.25;
				constant = 6830;
				reduceBy = 200000;
			}
			else if ( propertyPrice >= 250000 && propertyPrice < 300000 ) {
				rate = 4.75;
				constant = 8955;
				reduceBy = 250000;
			}
			else if ( propertyPrice >= 300000 && propertyPrice < 500000 ) {
				rate = 5;
				constant = 11330;
				reduceBy = 300000;
			}
			else if ( propertyPrice >= 500000 ) {
				rate = 5.5;
				constant = 21330;
				reduceBy = 500000;
			}
			break;

		case "QLD":
			// http://www.osr.qld.gov.au/duties/about-duties/rates-of-duty.shtml
			//http://www.legislation.qld.gov.au/Bills/54PDF/2012/TreasCostLivB12.pdf
			//reviewed 26/6/13 - GT & BC - no change

			// If Primary Residence and House -Home concession rate applies
			if ( primaryResidence && securityType === "House" ) {
				rateType = "Part";
				if ( propertyPrice > 0 && propertyPrice < 350000 ) {
					rate = 1;
					constant = 0;
					reduceBy = 0;
				}
				else if ( propertyPrice >= 350000 && propertyPrice < 540000 ) {
					rate = 3.5;
					constant = 3500;
					reduceBy = 350000;
				}
				else if ( propertyPrice >= 540000 && propertyPrice < 1000000 ) {
					rate = 4.5;
					constant = 10150;
					reduceBy = 540000;
				}
				else if ( propertyPrice >= 1000000 ) {
					rate = 5.75;
					constant = 30850;
					reduceBy = 1000000;
				}

				// https://www.osr.qld.gov.au/duties/transfer-duty/exemptions-and-concessions/home-transfer-duty-concession-rates.shtml
				if (firstHomeBuyer) {
					rateType = "Part";

					if ( propertyPrice < 505000 ) {
						constant += -8750;
					}
					else if ( propertyPrice < 550000 ) {
						constant += -8750 + (Math.ceil((propertyPrice - 504999) / 5000) * 875);
					}
				}
			}
			else {
				rateType = "Part";

				if ( propertyPrice > 0 && propertyPrice < 5000 ) {
					rate = 0;
					constant = 0;
					reduceBy = 0;
				}
				else if ( propertyPrice > 5000 && propertyPrice <= 75000 ) {
					rate = 1.5;
					constant = 0;
					reduceBy = 5000;
				}
				else if ( propertyPrice > 75000 && propertyPrice <= 540000 ) {
					rate = 3.5;
					constant = 1050;
					reduceBy = 75000;
				}
				else if ( propertyPrice > 540000 && propertyPrice <= 1000000 ) {
					rate = 4.5;
					constant = 17325;
					reduceBy = 540000;
				}
				else if ( propertyPrice > 1000000 ) {
					rate = 5.75;
					constant = 38025;
					reduceBy = 1000000;
				}

				if ( firstHomeBuyer && securityType === "Vacant Land" ) {
					rateType = "Part";

					if ( propertyPrice <= 250000 ) {
						constant = -7175;
					}
					else if ( propertyPrice < 400000 ) {
						constant += -7175 + (Math.ceil((propertyPrice - 259999) / 10000) * 475);
					}
				}
			}
			break;

		case "NT": // update 7th feb 2013
			// http://www.treasury.nt.gov.au/TaxesRoyaltiesAndGrants/StampDuty/StampDutyCalculators/Pages/Conveyance-Calculator.aspx

			reduceBy = 0;
			constant = 0;

			if ( propertyPrice > 0 && propertyPrice < 525000 ) {
				rate = 0.06571441;
				rateType = "NTSD";
			}
			else if ( propertyPrice >= 525000 && propertyPrice < 3000000 ) {
				rate = 4.95;
				rateType = "Percentage";
			}
			else if (propertyPrice >= 3000000) {
				rate = 5.45;
				rateType = "Percentage";
			}
			break;

		case "WA":
			// http://www.finance.wa.gov.au/cms/content.aspx?id = 2079
			//reviewed 26/6/13 - GT & BC - no change
			
			rateType = "Part";

			//FHOR - Dwelling
			if(
				firstHomeBuyer && 
				primaryResidence && 
				securityType === "Vacant Land" &&
				propertyPrice <= 400000 
			) {
				if ( propertyPrice > 0 && propertyPrice <= 300000 ) {
					rate = 0;
					constant = 0;
					reduceBy = 0;
				}
				else if ( propertyPrice > 300000 && propertyPrice <= 400000 ) {
					rate = 13.01;
					constant = 0;
					reduceBy = 300000;
				}
			}
			//FHOR + Dwelling
			else if (
				firstHomeBuyer && 
				primaryResidence &&
				securityType === "House" &&
				propertyPrice <= 530000 
			) {
				if ( propertyPrice > 0 && propertyPrice <= 430000 ) {
					rate = 0;
					constant = 0;
					reduceBy = 0;
				}
				else if ( propertyPrice > 430000 && propertyPrice <= 530000 ) {
					rate = 19.19;
					constant = 0;
					reduceBy = 430000;
				}
			}
			//concessional - http://www.finance.wa.gov.au/cms/content.aspx?id = 2054
			else if ( primaryResidence && propertyPrice <= 116000 ) {
				if ( propertyPrice > 0 && propertyPrice <= 100000 ) {
					rate = 1.5;
					constant = 0;
					reduceBy = 0;
				}
				else if ( propertyPrice > 100000 && propertyPrice <= 200000 ) {
					rate = 4.39;
					constant = 1500;
					reduceBy = 100000;
				}
			}
			//Residential rate - http://www.finance.wa.gov.au/cms/content.aspx?id = 2071
			else if ( securityType === "House" ) {
				if ( propertyPrice > 0 && propertyPrice <= 120000 ) {
					rate = 1.9;
					constant = 0;
					reduceBy = 0;
				}
				else if ( propertyPrice > 120000 && propertyPrice <= 150000 ) {
					rate = 2.85;
					constant = 2280;
					reduceBy = 120000;
				}
				else if ( propertyPrice > 150000 && propertyPrice <= 360000 ) {
					rate = 3.8;
					constant = 3135;
					reduceBy = 150000;
				}
				else if ( propertyPrice > 360000 && propertyPrice <= 725000 ) {
					rate = 4.75;
					constant = 11115;
					reduceBy = 360000;
				}
				else if ( propertyPrice > 725000 ) {
					rate = 5.15;
					constant = 28453;
					reduceBy = 725000;
				}
			}
			// normal - non residential rate  - http://www.finance.wa.gov.au/cms/content.aspx?id = 2063
			else {
				if ( propertyPrice > 0 && propertyPrice <= 80000 ) {
					rate = 1.9;
					constant = 0;
					reduceBy = 0;
				}
				else if ( propertyPrice > 80000 && propertyPrice <= 100000 ) {
					rate = 2.85;
					constant = 1520;
					reduceBy = 80000;
				}
				else if ( propertyPrice > 100000 && propertyPrice <= 250000 ) {
					rate = 3.8;
					constant = 2090;
					reduceBy = 100000;
				}
				else if ( propertyPrice > 250000 && propertyPrice <= 500000 ) {
					rate = 4.75;
					constant = 7790;
					reduceBy = 250000;
				}
				else if ( propertyPrice > 500000 ) {
					rate = 5.15;
					constant = 19665;
					reduceBy = 500000;
				}
			}
			break;

		case "ACT":
			// http://www.revenue.act.gov.au/duties/land_and_improvements
			// http://www.revenue.act.gov.au/home_buyer_assistance/home_buyer_duty_concession/1_july_2011_-_31_december_2011
			// online govt calculator - http://www.revenue.act.gov.au/calculators
			
			rateType = "Part";
			if (
				primaryResidence &&
				propertyPrice < 317600 &&
				securityType === "Vacant Land" &&
				homeBuyerConcessionACT
			) {
				if ( propertyPrice > 0 && propertyPrice <= 272200 ) {
					rate = 0;
					constant = 20;
					reduceBy = 0;
				}
				else if ( propertyPrice > 272200 && propertyPrice < 317600 ){
					rate = 13.55;
					constant = 0;
					reduceBy = 272200;
				}
			}
			else if ( 
				primaryResidence && 
				propertyPrice < 585000 && 
				securityType !== "Vacant Land" && 
				homeBuyerConcessionACT
			) {
				if ( propertyPrice > 0 && propertyPrice <= 455000 ) {
					rate = 0;
					constant = 20;
					reduceBy = 0;
				}
				else if ( propertyPrice > 455000 && propertyPrice < 585000 ) {
					rate = 13.60;
					constant = 0;
					reduceBy = 455000;
				}
			}
			else {
				if ( propertyPrice > 0 && propertyPrice <= 1000 ) {
					rate = 0;
					constant = 20;
					reduceBy = 0;
				}
				else if ( propertyPrice > 1000 && propertyPrice <= 200000 ) {
					rate = 1.48;
					constant = 0;
					reduceBy = 0;
				}
				else if ( propertyPrice > 200000 && propertyPrice <= 300000 ) {
					rate = 2.5;
					constant = 2960;
					reduceBy = 200000;
				}
				else if ( propertyPrice > 300000 && propertyPrice <= 500000 ) {
					rate = 4;
					constant = 5460;
					reduceBy = 300000;
				}
				else if ( propertyPrice > 500000 && propertyPrice <= 750000 ) {
					rate = 5.00;
					constant = 13460;
					reduceBy = 500000;
				}
				else if ( propertyPrice > 750000 && propertyPrice <= 1000000 ) {
					rate = 6.5;
					constant = 25960;
					reduceBy = 750000;
				}
				else if ( propertyPrice > 1000000 && propertyPrice <= 1454999 ) {
					rate = 7;
					constant = 42210;
					reduceBy = 1000000;
				}
				else if ( propertyPrice >= 1455000 ) {
					rate = 5.09;
					constant = 0;
					reduceBy = 0;
				}
			}
			break;

		case "TAS":
			// http://www.sro.tas.gov.au/domino/dtf/SROWebsite.nsf/v-all/380146A04610A996CA25758B000686E0?OpenDocument&menuitem=Property%20Buyers
			
			rateType = "Part";
			if ( propertyPrice > 0 && propertyPrice <= 3000 ) {
				rate = 0;
				constant = 50;
				reduceBy = 0;
			}
			else if ( propertyPrice > 3000 && propertyPrice <= 25000 ) {
				rate = 1.75;
				constant = 50;
				reduceBy = 3000;
			}
			else if ( propertyPrice > 25000 && propertyPrice <= 75000 ) {
				rate = 2.25;
				constant = 435;
				reduceBy = 25000;
			}
			else if ( propertyPrice > 75000 && propertyPrice <= 200000 ) {
				rate = 3.5;
				constant = 1560;
				reduceBy = 75000;
			}
			else if ( propertyPrice > 200000 && propertyPrice <= 375000 ) {
				rate = 4;
				constant = 5935;
				reduceBy = 200000;
			}
			else if ( propertyPrice > 375000 && propertyPrice <= 725000 ) {
				rate = 4.25;
				constant = 12935;
				reduceBy = 375000;
			}
			else if ( propertyPrice > 725000 ) {
				rate = 4.50;
				constant = 27810;
				reduceBy = 725000;
			}
			break;

	} // end of "switch(state)"

	cost = stampDuty(propertyPrice, rate, constant, reduceBy, rateType);
	cost = cost - fhbConcession;
	cost = cost - (cost * hbbConcession);  // NSW Home Builder Bonus Concession

	// http://www.sro.vic.gov.au/sro/SROnav.nsf/LinkView/8BD89ABA20F79314CA257894001F0F652BBCCD3DEA42D638CA2575D800089C9A/$file/2011-12%20HomeBuyers%20Factsheet%20-%20Final%20x%202.pdf
	// FHB concession of 20% available upto $600,000
	// FHB  concession of additional 10% from 1st jan' 2013
	if (
		state === "VIC" && 
		primaryResidence && 
		firstHomeBuyer && 
		propertyPrice <= 600000
	) {
		cost = cost - (cost * 50 / 100);
	}

	cost = cost > 0 ? cost : 0;
	return  Math.round(cost);
}

function stampDuty(value, rate, constant, reduceBy, rateType) {
	var stampDutyCost = 0;

	switch (rateType) {
		case "Percentage":
			rate = rate / 100;
			stampDutyCost = (value - reduceBy) * rate + constant;
			break;
		case "Number":
			stampDutyCost = (value - reduceBy) * rate + constant;
			break;
		case "Part":
			stampDutyCost = Math.ceil((value - reduceBy) / 100) * rate + constant;
			break;
		case "NTSD":
			var V = value / 1000;
			stampDutyCost = Math.pow(V, 2) * rate + (15 * V);
			break;
	}
	return stampDutyCost;
}