function showRepayments() {
	var loanAmount = document.getElementById("loan-amount").value;
	var loanTerm = document.getElementById("loan-term").value;
	var rate = document.getElementById("rate").value;
	var repaymentFrequency = document.getElementById("repayment-frequency").value;
	var interestOnly = document.getElementById("interest-only").checked;
	
	if (loanAmount.trim().length === 0 || !loanAmount.trim()) {
		loanAmount = document.getElementById("loan-amount").placeholder;
	}
	if (loanTerm.trim().length === 0 || !loanTerm.trim()) {
		loanTerm = document.getElementById("loan-term").placeholder;
	}
	if (rate.trim().length === 0 || !rate.trim()) {
		rate = document.getElementById("rate").placeholder;
	}
	
	var repaymentAmount = calculatePayment(loanAmount, rate, loanTerm, repaymentFrequency, interestOnly);
	var paymentsSchedule = computeSchedule(loanAmount, rate, loanTerm, repaymentFrequency, repaymentAmount);
	
	if (repaymentFrequency === 'Weekly-acc') {
		repaymentAmount = (repaymentAmount / 4).toFixed(2);
	}
	else if (repaymentFrequency === 'Fortnightly-acc') {
		repaymentAmount = (repaymentAmount / 2).toFixed(2);
	}
			
	document.getElementById("repayments-label").textContent = '$' + repaymentAmount.toLocaleString();
	document.getElementById("frequency-label").textContent = '(' + repaymentFrequency + ')';
	document.getElementById("total-repayments-label").textContent = '$' + paymentsSchedule.totalRepayments.toLocaleString();
	document.getElementById("total-interest-label").textContent = '($' + paymentsSchedule.totalInterest.toLocaleString() + ' total interest paid)';
	
	var j = 0;
	var step = 0;
	var dataPointers = [];
	var schedule = paymentsSchedule.schedule;
	
	if (repaymentFrequency === 'Monthly'  || repaymentFrequency === 'Weekly-acc' || repaymentFrequency === 'Fortnightly-acc') {
		step = 12;
	}
	else if (repaymentFrequency	=== 'Fortnightly') {
		step = 26;
	}
	else if (repaymentFrequency	=== 'Weekly') {
		step = 52;
	}
	
	for (var i = 0; i < schedule.length; i = i + step) {
		dataPointers[j] = {x: +j, y: (+(schedule[i][3])).toFixed(2)};
		j++;
	}
	
	dataPointers[j] = {x: j, y: 0};
	
	var chartData = [
		{
			strokeColor : "rgba(51, 176, 234, 1)",
			pointColor : "rgba(51, 122, 183, 1)",
			pointStrokeColor : "rgba(51, 176, 234, 1)",
			data: dataPointers
		}
	];
	
	var ctx = document.getElementById("canvas").getContext("2d");
	window.myLine = new Chart(ctx).Scatter(chartData, {
		responsive: true,
		scaleLineColor: "rgba(204, 204, 204, 1)",
		scaleLabel: "$<%=value%>",
		scaleArgLabel: "<%=value%> years"
	});
}
			
function showExtraRepayments() {
	var loanAmount = document.getElementById("loan-amount").value;
	var loanTerm = document.getElementById("loan-term").value;
	var rate = document.getElementById("rate").value;
	var extraRepayment = document.getElementById("extra").value;
	var repaymentFrequency = document.getElementById("repayment-frequency").value;
	var interestOnly = false;
	
	if (loanAmount.trim().length === 0 || !loanAmount.trim()) {
		loanAmount = document.getElementById("loan-amount").placeholder;
	}
	if (loanTerm.trim().length === 0 || !loanTerm.trim()) {
		loanTerm = document.getElementById("loan-term").placeholder;
	}
	if (rate.trim().length === 0 || !rate.trim()) {
		rate = document.getElementById("rate").placeholder;
	}
	if (extraRepayment.trim().length === 0 || !extraRepayment.trim()) {
		extraRepayment = document.getElementById("extra").placeholder;
	}
	
	var repaymentAmount = calculatePayment(loanAmount, rate, loanTerm, repaymentFrequency, interestOnly);
	var extraRepaymentAmount = (parseFloat(repaymentAmount) + parseFloat(extraRepayment)).toFixed(2);
	var paymentsSchedule = computeSchedule(loanAmount, rate, loanTerm, repaymentFrequency, repaymentAmount);
	var extraRepaymentPaymentsSchedule = computeSchedule(loanAmount, rate, loanTerm, repaymentFrequency, extraRepaymentAmount);
	
	var multiplier = Math.pow(10, 1);
	var yearsSaved = Math.round( (paymentsSchedule.timeToPay - extraRepaymentPaymentsSchedule.timeToPay) * multiplier ) / multiplier;
	
	if (repaymentFrequency === 'Weekly-acc') {
		extraRepaymentAmount = (extraRepaymentAmount / 4).toFixed(2);
	}
	else if (repaymentFrequency === 'Fortnightly-acc') {
		extraRepaymentAmount = (extraRepaymentAmount / 2).toFixed(2);
	}
			
	document.getElementById("repayments-label").textContent = '$' + repaymentAmount.toLocaleString();
	document.getElementById("frequency-label").textContent = '(' + repaymentFrequency + ')';
	document.getElementById("total-repayments-label").textContent = '$' + extraRepaymentPaymentsSchedule.totalRepayments.toLocaleString();
	document.getElementById("total-interest-label").textContent = '($' + extraRepaymentPaymentsSchedule.totalInterest.toLocaleString() + ' total interest paid)';
	
	document.getElementById("total-saving-label").textContent = '$' + (paymentsSchedule.totalInterest - extraRepaymentPaymentsSchedule.totalInterest).toLocaleString();
	document.getElementById("years-saved-label").textContent = (yearsSaved < 1 ? (yearsSaved + ' Year') : (yearsSaved + ' Years'));
	
	var j = 0;
	var k = 0;
	var step = 0;
	var paymentsDataPointers = [];
	var extraRepaymentsDataPointers = [];
	var schedule = paymentsSchedule.schedule;
	var extraRepaymentSchedule = extraRepaymentPaymentsSchedule.schedule;
	
	if (repaymentFrequency === 'Monthly'  || repaymentFrequency === 'Weekly-acc' || repaymentFrequency === 'Fortnightly-acc') {
		step = 12;
	}
	else if (repaymentFrequency	=== 'Fortnightly') {
		step = 26;
	}
	else if (repaymentFrequency	=== 'Weekly') {
		step = 52;
	}
	
	for (var i = 0; i < schedule.length; i = i + step) {
		paymentsDataPointers[j] = {x: +j, y: (+(schedule[i][3])).toFixed(2)};
		j++;
	}
	
	for (var i = 0; i < extraRepaymentSchedule.length; i = i + step) {
		extraRepaymentsDataPointers[k] = {x: +k, y: (+(extraRepaymentSchedule[i][3])).toFixed(2)};
		k++;
	}
	
	paymentsDataPointers[j] = {x: j, y: 0};
	extraRepaymentsDataPointers[k] = {x: k, y: 0};
	
	var chartData = [
		{
			strokeColor : "rgba(51, 176, 234, 1)",
			pointColor : "rgba(51, 122, 183, 1)",
			pointStrokeColor : "rgba(51, 176, 234, 1)",
			data: paymentsDataPointers
		},
		{
			strokeColor : "rgba(218,71,65, 0.8)",
			pointColor : "rgba(218,71,65, 0.8)",
			pointStrokeColor : "rgba(218,71,65, 0.8)",
			data: extraRepaymentsDataPointers
		}
	];
	
	var ctx = document.getElementById("canvas").getContext("2d");
	window.myLine = new Chart(ctx).Scatter(chartData, {
		responsive: true,
		scaleLineColor: "rgba(204, 204, 204, 1)",
		scaleLabel: "$<%=value%>",
		scaleArgLabel: "<%=value%> years"
	});
	
}

function calculatePayment(principal, interestRate, term, paymentFrequency, interestOnly) {
	var weekly = 52;
	var fortnightly = 26;
	var monthly = 12;
	var paymentsPerYear = undefined;
		
	if (paymentFrequency === 'Monthly' || paymentFrequency === 'Weekly-acc' || paymentFrequency === 'Fortnightly-acc') {
		paymentsPerYear = monthly;
	}
	else if (paymentFrequency === 'Fortnightly') {
		paymentsPerYear = fortnightly;
	}
	else if (paymentFrequency === 'Weekly') {
		paymentsPerYear = weekly;
	}

	var denominator;
	var numerator;
	var interestRatePerPeriod;
	var numberOfPayments;

	interestRatePerPeriod = interestRate / paymentsPerYear;
	numberOfPayments = term * paymentsPerYear;

	interestRatePerPeriod /= 100;
	var repayment;

	if (!interestOnly && numberOfPayments > 0) {
		numerator = interestRatePerPeriod * Math.pow(1 + interestRatePerPeriod, numberOfPayments);
		denominator = Math.pow(1 + interestRatePerPeriod, numberOfPayments) - 1;
		repayment = principal * (numerator / denominator);
	}
	else {
		repayment = principal * interestRatePerPeriod;
	}
	
	return repayment.toFixed(2);
}

function computeSchedule(principal, interestRate, term, paymentFrequency, repayment) {
	var weekly = 52;
	var fortnightly = 26;
	var monthly = 12;
	var paymentsPerYear = undefined;
		
	if (paymentFrequency === 'Monthly' || paymentFrequency === 'Weekly-acc' || paymentFrequency === 'Fortnightly-acc') {
		paymentsPerYear = monthly;
	}
	else if (paymentFrequency === 'Fortnightly') {
		paymentsPerYear = fortnightly;
	}
	else if (paymentFrequency === 'Weekly') {
		paymentsPerYear = weekly;
	}
	
	var numberOfPayments = term * paymentsPerYear;
	
	var balance = principal;
	var schedule = [];
	var totalInterest = 0;
	var endOfLoan = false;
	
	for(var i = 0; i < numberOfPayments; i++) {
		var interest = balance * (interestRate / 100 / paymentsPerYear);
		var principle = +(repayment - interest);
		var row = undefined;
		if (i === (numberOfPayments - 1)) {
			row = [i, 0, 0, 0];
		}
		else if (interest < 0 && balance < 0) {
			endOfLoan = true;
		}
		else {
			row = [i, principle > -0.01 ? principle : 0, interest > -0.01 ? interest : 0, balance > -0.01 ? balance : 0];
		}
		
		if (row !== undefined)
		{
			schedule.push(row);
		}
		balance -= principle;
		totalInterest += interest;
		
		if (endOfLoan) {
			numberOfPayments = i;
			break;
		}
	}
	
	totalInterest = +totalInterest.toFixed();
	var totalRepayments = (numberOfPayments * repayment);
	var timeToPay = numberOfPayments / paymentsPerYear;
	
	var objToReturn = {
		schedule: schedule, 
		totalRepayments: totalRepayments, 
		totalInterest: totalInterest, 
		timeToPay: timeToPay, 
		numberOfPayments: numberOfPayments
	};
	
	return objToReturn;
}

function calculateBalance(principal, paymentAmount, numberOfPayments, interestRate, term) {
	var balance;
	var cumulativeInterest;
	var interestRatePerPeriod = interestRate/12;
	
	interestRatePerPeriod/=100;
	cumulativeInterest = Math.pow(1 + interestRatePerPeriod, numberOfPayments);
	balance = (principal * cumulativeInterest) - ((paymentAmount / interestRatePerPeriod) * (cumulativeInterest - 1));
	
	return balance;
}